@@ -95,7 +95,8 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="Openjourney",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://civitai.com/api/download/models/96",
+        # weights_url="https://civitai.com/api/download/models/96",
+        weights_url="https://huggingface.co/prompthero/openjourney-v2/resolve/main/openjourney-v2-unpruned.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
@@ -107,13 +108,13 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="Protogen-Photo",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://civitai.com/api/download/models/4048",
+        weights_url="https://huggingface.co/darkstorm2150/Protogen_x3.4_Official_Release/resolve/main/ProtoGen_X3.4.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
         short_name="Protogen-PhotoV2",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://civitai.com/api/download/models/4229",
+        weights_url="https://huggingface.co/darkstorm2150/Protogen_v5.3_Official_Release/resolve/main/ProtoGen_X5.3.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
@@ -125,7 +126,7 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="SynthwavePunk",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://civitai.com/api/download/models/1144",
+        weights_url="https://huggingface.co/zipp425/synthwavePunk/resolve/main/synthwavePunk_v2.ckpt",
         default_image_size=512,
     ),
     ModelConfig(
